@@ -136,7 +136,7 @@ def parsing_face(input_img, output_path=''):
     parsing = out.squeeze(0).cpu().numpy().argmax(0)
 
     res_img = vis_parsing_maps(image, parsing, stride=1, save_im=False)
-    if out_path == '':
+    if output_path == '':
         return res_img
     else:
         cv2.imwrite(output_path, res_img, [int(cv2.IMWRITE_JPEG_QUALITY), 100])
